Struct AgentReply

pub struct AgentReply;
A utility struct for creating act_on response futures.

Implementations

Source

impl AgentReply

pub fn immediate() -> Pin<Box<impl Future<Output = ()> + Sized>>

Creates a no-op (no operation) future.

This method returns a future that does nothing and completes immediately. It’s useful in situations where you need to provide a future but don’t want it to perform any actual work.

Returns

A pinned boxed future that resolves immediately without doing anything.

pub fn from_async<F>(future: F) -> Pin<Box<F>>
where F: Future<Output = ()> + Sized,

Wraps a future in a pinned box.

This method is useful for converting a future into a pinned boxed future, which is required returning from async act_on message handlers.

Arguments
  • future - The future to be wrapped.
Returns

A pinned boxed future.