pub struct AgentReply;Expand description
A utility struct for creating act_on response futures.
Implementations
Sourceimpl AgentReply
impl AgentReply
Sourcepub fn immediate() -> Pin<Box<impl Future<Output = ()> + Sized>>
pub fn immediate() -> Pin<Box<impl Future<Output = ()> + Sized>>
Creates a no-op (no operation) future.
This method returns a future that does nothing and completes immediately. It’s useful in situations where you need to provide a future but don’t want it to perform any actual work.
Returns
A pinned boxed future that resolves immediately without doing anything.
Sourcepub fn from_async<F>(future: F) -> Pin<Box<F>>
pub fn from_async<F>(future: F) -> Pin<Box<F>>