acton_core::prelude

Struct ManagedAgent

pub struct ManagedAgent<AgentState, ManagedAgent: Default + Send + Debug + 'static> {
    pub model: ManagedAgent,
    /* private fields */
}
A managed agent is a wrapper around an actor that provides a set of lifecycle hooks and message handling reactors.

Fields

model: ManagedAgent

The actor model.

Implementations

Source

impl<State: Default + Send + Debug + 'static> ManagedAgent<Idle, State>

pub fn act_on<M>( &mut self, message_processor: impl for<'a> Fn(&'a mut ManagedAgent<Started, State>, &'a mut MessageContext<M>) -> Pin<Box<dyn Future<Output = ()> + Sync + Send + 'static>> + Send + Sync + 'static, ) -> &mut Self
where M: ActonMessage + Clone + Send + Sync + 'static,

Adds an asynchronous message handler for a specific message type.

Parameters
  • message_processor: The function to handle the message.
pub fn after_start<F, Fut>(&mut self, f: F) -> &mut Self
where F: for<'b> Fn(&'b ManagedAgent<Started, State>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + Sync + 'static,

Sets the reactor to be called when the actor wakes up.

Parameters
  • life_cycle_event_reactor: The function to be called.
pub fn before_start<F, Fut>(&mut self, f: F) -> &mut Self
where F: for<'b> Fn(&'b ManagedAgent<Started, State>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + Sync + 'static,

Sets the reactor to be called when the actor wakes up.

Parameters
  • life_cycle_event_reactor: The function to be called.
pub fn after_stop<F, Fut>(&mut self, f: F) -> &mut Self
where F: for<'b> Fn(&'b ManagedAgent<Started, State>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + Sync + 'static,

Sets the reactor to be called when the actor stops processing messages in its mailbox.

Parameters
  • life_cycle_event_reactor: The function to be called.
pub fn before_stop<F, Fut>(&mut self, f: F) -> &mut Self
where F: for<'b> Fn(&'b ManagedAgent<Started, State>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + Sync + 'static,

Sets the reactor to be called just before the actor stops processing messages in its mailbox.

Parameters
  • life_cycle_event_reactor: The function to be called.
pub async fn create_child( &self, name: String, ) -> Result<ManagedAgent<Idle, State>>

Creates and supervises a new actor with the given ID and state.

Parameters
  • id: The identifier for the new actor.
Returns

A new Actor instance in the idle state.

pub async fn start(self) -> AgentHandle

Starts the actor and transitions it to the running state.

Source

impl<Agent: Default + Send + Debug + 'static> ManagedAgent<Started, Agent>

pub fn new_envelope(&self) -> Option<OutboundEnvelope>

Creates a new outbound envelope for the actor.

Returns

An optional OutboundEnvelope if the context’s outbox is available.

pub fn new_parent_envelope(&self) -> Option<OutboundEnvelope>

Creates a new parent envelope for the actor.

Returns

A clone of the parent’s return envelope.

Source

impl<ActorState, ManagedEntity: Default + Send + Debug + 'static> ManagedAgent<ActorState, ManagedEntity>

pub fn id(&self) -> &Ern

Returns the unique identifier of the actor.

pub fn name(&self) -> &str

Returns the name of the actor.

pub fn handle(&self) -> &AgentHandle

Returns the handle of the actor.

pub fn parent(&self) -> &Option<AgentHandle>

Returns the parent of the actor.

pub fn broker(&self) -> &AgentHandle

Returns the broker of the actor.

pub fn runtime(&self) -> &AgentRuntime

Returns the app runtime.